==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/plugins/agendaplugin/agendamode.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main Developers :                                                    *
 *       Guillaume Denry <guillaume.denry@gmail.com>                       *
 *       Eric MAEKER, MD <eric.maeker@gmail.com>                           *
 *   Contributors :                                                        *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef AGENDAMODE_H
#define AGENDAMODE_H

#include <coreplugin/modemanager/basemode.h>

#include <QStackedWidget>
#include <QModelIndex>

/**
 * \file agendamode.h
 * \author Eric MAEKER <eric.maeker@gmail.com>
 * \version 0.6.0
 * \date 17 Jun 2011
*/

namespace Agenda {
class UserCalendarModel;

namespace Internal {
class UserCalendarViewer;

class AgendaMode : public Core::BaseMode
{
    Q_OBJECT
public:
    explicit AgendaMode(QObject *parent = 0);

    QString name() const;

private Q_SLOTS:
    void postCoreInitialization();
    void userChanged();
    void rowsChanged(const QModelIndex &parent, int start, int end);

private:
    QStackedWidget *m_Stack;
    UserCalendarViewer *m_Viewer;
    UserCalendarModel *m_UserCalendarModel;
};

}  // End namespace Internal
}  // End namespace Agenda


#endif // AGENDAMODE_H

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/plugins/agendaplugin/agendamode.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main Developers:                                                     *
 *       Guillaume Denry <guillaume.denry@gmail.com>                       *
 *       Eric MAEKER, MD <eric.maeker@gmail.com>                           *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef AGENDA_AGENDAMODE_H
#define AGENDA_AGENDAMODE_H

#include <coreplugin/modemanager/imode.h>

#include <QStackedWidget>
#include <QModelIndex>

/**
 * \file agendamode.h
 * \author Eric MAEKER
 * \version 0.6.0
 * \date 17 Jun 2011
*/

namespace Agenda {
class UserCalendarModel;

namespace Internal {
class UserCalendarViewer;

class AgendaMode : public Core::IMode
{
    Q_OBJECT
public:
    explicit AgendaMode(QObject *parent = 0);

private Q_SLOTS:
    void postCoreInitialization();
    void userChanged();
    void rowsChanged(const QModelIndex &parent, int start, int end);

private:
    void updateEnableState();

private:
    QStackedWidget *m_Stack;
    UserCalendarViewer *m_Viewer;
    UserCalendarModel *m_UserCalendarModel;
};

}  // End namespace Internal
}  // End namespace Agenda


#endif // AGENDA_AGENDAMODE_H
